California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 068 - AUTHORIZES BONDS FUNDING PARKS, NATURAL RESOURCES PROTECTION, CLIMATE ADAPTATION, WATER QUALITY AND SUPPLY, AND FLOOD PROTECTION. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1401983 | LOS ANGELES WATERKEEPER (NONPROFIT 501 (C) (3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1398230 | COMMITTEE FOR CLEAN WATER NATURAL RESOURCES AND PARKS, YES ON PROPOSITION 68 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1399547 | YES ON PROPOSITION 68 - CALIFORNIANS FOR CLEAN WATER AND SAFE PARKS, SPONSORED BY CONSERVATION GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1272719 | CONSERVATION ACTION FUND, SPONSORED BY ENVIRONMENTAL GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
891688 | CALIFORNIA PARK & RECREATION SOCIETY INC. SUPPORTING CLEAN WATER, NATURAL RESOURCES & PARKS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400733 | FUND FOR A BETTER FUTURE ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1403310 | ENVIRONMENT CALIFORNIA NONPROFIT 501(C)(4) FOR PROP 68 | SUPPORT